@@ -21,6 +21,7 @@ from ..overrides import overrides
 class BaseBot:
     def __init__(self):
         self.irc: Irc = None
+        self._running = False
 
     # region events
 
@@ -29,6 +30,13 @@ class BaseBot:
         triggered when the bot connects to all the channels specified in the config file
         """
 
+    async def on_raw_message(self, msg: Message):
+        """
+        triggered the instant a message is received,
+        this message can be any message received,
+        including twitches messages that do not have any useful information
+        """
+
     async def on_privmsg_sent(self, msg: str, channel: str, sender: str) -> None:
         """
         triggered when the bot sends a privmsg
@@ -85,6 +93,12 @@ class BaseBot:
         """
         print(f'joined #{channel.name}')
 
+    async def on_channel_subscription(self, channel: Channel, msg: Message):
+        """
+        triggered when a user subscribes
+        """
+        print(f'subscribed {msg}')
+
     # endregion
 
     def _create_channels(self):
@@ -169,8 +183,12 @@ class BaseBot:
             if k.value in self.__class__.__dict__ and k.value.startswith('on'):
                 setattr(self, k.value, v)
 
+    def shutdown(self):
+        self._running = False
+
     def run(self):
         """runs/starts the bot, this is a blocking function that starts the mainloop"""
+        self._running = True
         get_event_loop().run_until_complete(self._mainloop())
 
     async def _mainloop(self):
@@ -186,13 +204,17 @@ class BaseBot:
         await self.on_connected()
         await trigger_mod_event(Event.on_connected)
 
-        while True:
+        while self._running:
             raw_msg = await self.irc.get_next_message()
 
             if not raw_msg:
                 continue
 
             msg = Message(raw_msg, irc=self.irc, bot=self)
+            await self.on_raw_message(msg)
+            get_event_loop().create_task(
+                trigger_mod_event(Event.on_raw_message, msg, channel=msg.channel_name))
+
             coro = mod_coro = None
             cmd: Command = (await self.get_command_from_msg(msg)
                             if msg.is_user_message and msg.author != cfg.nick
@@ -214,6 +236,10 @@ class BaseBot:
                 coro = self.on_channel_joined(msg.channel)
                 mod_coro = trigger_mod_event(Event.on_channel_joined, msg.channel, channel=msg.channel_name)
 
+            elif msg.type is MessageType.SUBSCRIPTION:
+                coro = self.on_channel_subscription(msg.channel, msg)
+                mod_coro = trigger_mod_event(Event.on_channel_subscription, msg.channel, msg, channel=msg.channel_name)
+
             elif msg.type is MessageType.PING:
                 self.irc.send_pong()
 
