@@ -1,8 +1,8 @@
-from typing import List, Tuple, TYPE_CHECKING
+from typing import List, Tuple, TYPE_CHECKING, Optional
 from .util import get_message_mentions
 from twitchbot.channel import Channel, channels
 from .irc import Irc
-from .regex import RE_PRIVMSG, RE_WHISPER, RE_JOINED_CHANNEL
+from .regex import RE_PRIVMSG, RE_WHISPER, RE_JOINED_CHANNEL, RE_USERNOTICE
 from .enums import MessageType
 from .util import split_message
 from .tags import Tags
@@ -14,15 +14,15 @@ if TYPE_CHECKING:
 
 class Message:
     def __init__(self, msg, irc=None, bot=None):
-        self.channel: Channel = None
-        self.author: str = None
-        self.content: str = None
+        self.channel: Optional[Channel] = None
+        self.author: Optional[str] = None
+        self.content: Optional[str] = None
         self.parts: List[str] = []
         self.type: MessageType = MessageType.NONE
         self.raw_msg: str = msg
-        self.receiver: str = None
+        self.receiver: Optional[str] = None
         self.irc: Irc = irc
-        self.tags: Tags = None
+        self.tags: Optional[Tags] = None
         self.emotes: List[Emote] = []
         self.mentions: Tuple[str] = ()
         self.bot: 'BaseBot' = bot
@@ -30,6 +30,15 @@ class Message:
         self._parse()
 
     def _parse(self):
+        m = RE_USERNOTICE.search(self.raw_msg)
+        if m:
+            self.tags = Tags(m['tags'])
+            self.channel = channels[m['channel']]
+            self.author = self.tags.all_tags.get('login')
+            self.content = m['content']
+            if self.tags.msg_id in {'sub', 'resub', 'subgift', 'anonsubgift', 'submysterygift'}:
+                self.type = MessageType.SUBSCRIPTION
+
         m = RE_PRIVMSG.search(self.raw_msg)
         if m:
             self.channel = channels[m['channel']]
@@ -72,6 +81,10 @@ class Message:
     def is_whisper(self):
         return self.type is MessageType.WHISPER
 
+    @property
+    def is_subscription(self):
+        return self.type is MessageType.SUBSCRIPTION
+
     @property
     def mention(self):
         return f'@{self.author}' if self.author else ''
@@ -114,3 +127,9 @@ class Message:
             return 'PING'
 
         return self.raw_msg
+
+    def __len__(self):
+        """
+        :return: the len() of self.parts
+        """
+        return len(self.parts)
