@@ -4,7 +4,7 @@ import re
 class Tags:
     def __init__(self, tags: str):
         self.all_tags = {name: value for name, value in _split_tags(tags)}
-        self.badges: dict = _parse_badges(self.all_tags.get('@badges'))
+        self.badges: dict = _parse_badges(self.all_tags.get('badges'))
         self.color: str = self.all_tags.get('color')
         self.display_name: str = self.all_tags.get('display-name')
         self.emotes: str = self.all_tags.get('emotes')
@@ -19,7 +19,9 @@ class Tags:
         self.bits: int = _try_parse_int(self.all_tags.get('bits'))
         self.bits_leader: int = self.all_tags.get('bits-leader')
         self.broadcaster: int = self.badges.get('broadcaster', 0)
+        self.msg_id: str = self.all_tags.get('msg-id')
 
+        # bit_leader is initially a string, it is then parsed into a int here
         if self.bits_leader:
             self.bits_leader = _try_parse_int(self.bits_leader.partition('/')[-1])
 
